@@ -41,12 +41,14 @@ namespace LongoMatch.Interfaces.GUI
 			string filterName, string extensionFilter);
 		string OpenFile(string title, string defaultName, string defaultFolder,
 			string filterName, string extensionFilter);
+		List<string> OpenFiles(string title, string defaultName, string defaultFolder,
+			string filterName, string extensionFilter);
 		string SelectFolder(string title, string defaultName, string defaultFolder,
 			string filterName, string extensionFilter);
 			
 		IBusyDialog BusyDialog(string message);
 			
-		List<Job> ConfigureRenderingJob (IPlayList playlist);
+		List<EditionJob> ConfigureRenderingJob (IPlayList playlist);
 		void ExportFrameSeries(Project openenedProject, Play play, string snapshotDir);
 		
 		ProjectDescription SelectProject(List<ProjectDescription> projects);
@@ -66,7 +68,7 @@ namespace LongoMatch.Interfaces.GUI
 		
 		void ManageJobs(IRenderingJobsManager manager);
 		
-		void TagPlay(Play play, TeamTemplate local, TeamTemplate visitor);
+		void TagPlay(Play play, TeamTemplate local, TeamTemplate visitor, bool showAllTags);
 		void DrawingTool(Image pixbuf, Play play, int stopTime);
 	}
 }
