@@ -67,6 +67,7 @@ namespace LongoMatch.Gui
 		//the player.mrl is diferent from the filename as it's an uri eg:file:///foo.avi
 		private string filename = null;
 		protected VolumeWindow vwin;
+		bool readyToSeek = false;
 
 
 		#region Constructors
@@ -105,9 +106,9 @@ namespace LongoMatch.Gui
 			}
 		}
 
-		public long CurrentTime {
+		public int CurrentTime {
 			get {
-				return player.CurrentTime;
+				return (int) player.CurrentTime;
 			}
 		}
 
@@ -125,6 +126,12 @@ namespace LongoMatch.Gui
 				vscale1.Value = (int)(value*25);
 			}
 		}
+		
+		public bool SeekingEnabled {
+			set {
+				timescale.Sensitive = value;
+			}
+		}
 
 		public bool FullScreen {
 			set {
@@ -211,6 +218,7 @@ namespace LongoMatch.Gui
 				//We handle this error async
 			}
 			detachbutton.Sensitive = true;
+			readyToSeek = false;
 		}
 
 		public void Play() {
@@ -242,6 +250,7 @@ namespace LongoMatch.Gui
 			SetSensitive();
 			timescale.Value=0;
 			timelabel.Text="";
+			SeekingEnabled = true;
 			player.CancelProgramedStop();
 		}
 
@@ -345,8 +354,12 @@ namespace LongoMatch.Gui
 			segmentStopTime = stop;
 			closebutton.Show();
 			vscale1.Value = 25;
-			player.SegmentSeek(start,stop, GetRateFromScale());
-			player.Play();
+			if (readyToSeek) {
+				player.SegmentSeek(start, stop, GetRateFromScale());
+				player.Play();
+			} else {
+				pendingSeek = new object[3] {start, stop, GetRateFromScale()};
+			}
 		}
 
 		public void CloseActualSegment() {
@@ -458,13 +471,13 @@ namespace LongoMatch.Gui
 		}
 
 		protected void OnReadyToSeek(object o, EventArgs args) {
+			readyToSeek = true;
 			if(pendingSeek != null) {
 				player.SegmentSeek((long)pendingSeek[0],
 				                   (long)pendingSeek[1],
 				                   (float)pendingSeek[2]);
 				player.Play();
 				pendingSeek = null;
-
 			}
 		}
 
